==> byteplus_rtc-3.51.1.tar.gz: lib/api/bytertc_range_audio_api.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'bytertc_audio_defines.dart';

/// Range audio instance
abstract class RTCRangeAudio {
  /// Enables/disables the range audio function.
  ///
  /// Range audio means that within a certain range in a same RTC room, the audio volume of the remote user received by the local user will be amplified/attenuated as the remote user moves closer/away. The audio coming from out of the range cannot be heard. See [RTCRangeAudio.updateReceiveRange] to set audio receiving range.
  ///
  /// You can call this API anytime before or after entering a room. To ensure a smooth switch to the range audio mode after entering the room, you need to call [RTCRangeAudio.updatePosition] before this API to set your own position coordinates, and then enable the range audio function.
  Future<void> enableRangeAudio(bool enable);

  /// Updates the audio receiving range for the local user.
  ///
  /// [range]: Audio receiving range.
  ///
  /// API call result:
  /// + 0: Success.
  /// + !0: Failure.
  Future<int?> updateReceiveRange(ReceiveRange range);

  /// Updates the coordinate of the local user's position in the rectangular coordinate system in the current room.
  ///
  /// [pos]: 3D coordinate values, the default value is `[0, 0, 0]`.
  ///
  /// API call result:
  /// + 0: Success.
  /// + !0: Failure.
  ///
  /// Notes:
  /// + After calling this API, you should call [RTCRangeAudio.enableRangeAudio] to enable range audio function to actually enjoy the range audio effect.
  Future<int?> updatePosition(Position pos);

  /// Set the volume attenuation mode of the range audio.
  ///
  /// After the attenuation mode is changed, the [RTCRangeAudioObserver.onRangeAudioInfo] callback will calculate and return the volume attenuation value based on the last attenuation mode you set.
  ///
  /// [type]: Volume attenuation mode, the default is linear attenuation.
  ///
  /// [coefficient]： Volume attenuation factor in exponential attenuation mode. The default value is 1.<br>
  /// The value range is `[0.1,100]`. It is recommended to set this value to `50`.<br>
  /// The higher the value, the faster the attenuation of the volume.
  ///
  /// API call result:
  /// + `0`: Success.
  /// + `-1`: Failure, because you called this API before calling [RTCRangeAudio.enableRangeAudio] to enable range audio or before entering the room.
  ///
  /// Notes: Set the volume attenuation range with [RTCRangeAudio.updateReceiveRange].
  Future<int?> setAttenuationModel({
    required AttenuationType type,
    required double coefficient,
  });

  /// Sets the flags to mark the user groups, within which the users talk without attenuation.
  ///
  /// + In the RTC room, if the flags of the users intersects with each other, the users talk without attenuation. <br>
  /// + For example, the user is a member of multiple teams, and teammates of the same team talks without attenuation. You can set the flag for each team, and includes the flags of the user's teams in the user's flags.
  ///
  /// [flags]: Array of flags.
  Future<void> setNoAttenuationFlags(List<String> flags);
}

==> byteplus_rtc-3.56.1.tar.gz: lib/api/bytertc_range_audio_api.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'bytertc_audio_defines.dart';

/// The range in which local user can hear audio with attenuation effect.
class ReceiveRange {
  /// The minimum distance at which the local user can hear the attenuated audio from remote users.
  ///
  /// The value must be ≥ 0, but ≤ max. <br>
  /// No attenuation effect for audio from distances less than this value you set.
  int min;

  /// The maximum distance at which the local user can hear audio from remote users.
  ///
  /// The value must be ≥ min, and > 0.  <br>
  /// Audio from distances larger than the value you set cannot be heard.
  int max;

  /// @nodoc
  ReceiveRange({
    this.min = 0,
    this.max = 1,
  });

  /// @nodoc
  Map<String, dynamic> toMap() {
    return <String, dynamic>{
      'min': min,
      'max': max,
    };
  }
}

/// Range audio instance
abstract class RTCRangeAudio {
  /// Enables/disables the range audio function.
  ///
  /// Range audio means that within a certain range in a same RTC room, the audio volume of the remote user received by the local user will be amplified/attenuated as the remote user moves closer/away. The audio coming from out of the range cannot be heard. See [RTCRangeAudio.updateReceiveRange] to set audio receiving range.
  ///
  /// You can call this API anytime before or after entering a room. To ensure a smooth switch to the range audio mode after entering the room, you need to call [RTCRangeAudio.updatePosition] before this API to set your own position coordinates, and then enable the range audio function.
  Future<void> enableRangeAudio(bool enable);

  /// Updates the audio receiving range for the local user.
  ///
  /// [range]: Audio receiving range.
  ///
  /// API call result:
  /// + 0: Success.
  /// + !0: Failure.
  Future<int?> updateReceiveRange(ReceiveRange range);

  /// Updates the coordinate of the local user's position in the rectangular coordinate system in the current room.
  ///
  /// [pos]: 3D coordinate values, the default value is `[0, 0, 0]`.
  ///
  /// API call result:
  /// + 0: Success.
  /// + !0: Failure.
  ///
  /// Notes:
  /// + After calling this API, you should call [RTCRangeAudio.enableRangeAudio] to enable range audio function to actually enjoy the range audio effect.
  Future<int?> updatePosition(Position pos);

  /// Set the volume attenuation mode of the range audio.
  ///
  /// [type]: Volume attenuation mode, the default is linear attenuation.
  ///
  /// [coefficient]: Volume attenuation factor in exponential attenuation mode. The default value is 1.<br>
  /// The value range is `[0.1,100]`. It is recommended to set this value to `50`.<br>
  /// The higher the value, the faster the attenuation of the volume.
  ///
  /// API call result:
  /// + `0`: Success.
  /// + `-1`: Failure, because you called this API before calling [RTCRangeAudio.enableRangeAudio] to enable range audio or before entering the room.
  ///
  /// Notes: Set the volume attenuation range with [RTCRangeAudio.updateReceiveRange].
  Future<int?> setAttenuationModel({
    required AttenuationType type,
    required double coefficient,
  });

  /// Sets the flags to mark the user groups, within which the users talk without attenuation.
  ///
  /// + In the RTC room, if the flags of the users intersects with each other, the users talk without attenuation. <br>
  /// + For example, the user is a member of multiple teams, and teammates of the same team talks without attenuation. You can set the flag for each team, and includes the flags of the user's teams in the user's flags.
  ///
  /// [flags]: Array of flags.
  Future<void> setNoAttenuationFlags(List<String> flags);
}
